/// <reference types="node" />
import { ExecOptions } from 'child_process';
import { SpawnOptions } from 'child_process';
import $ from './spellu-engine';
declare namespace influe {
}
declare namespace influe {
    const metadata: {
        name: string;
        version: any;
    };
}
declare namespace influe {
    function wrapInArray<T>(object?: T | T[]): T[];
    function mapObject<T1, T2>(object: {
        [key: string]: T1;
    }, converter: (_: T1) => T2): {
        [key: string]: T2;
    };
}
declare namespace influe {
    type Map<T = any> = {
        [name: string]: T;
    };
    type ConfigDefinition = {
        debug?: boolean;
        path?: string;
        data?: Map;
        event?: EventDefinition[];
        file?: FileDefinition[];
        task?: TaskDefinition[];
    };
    type EventDefinition = {
        id?: string;
        time?: EventTimeDefinition;
        file?: EventFileDefinition;
        key?: EventKeyDefinition;
        make?: MakeDefinition | MakeDefinition[];
        run?: string | string[];
        enabled?: boolean;
    };
    type EventTimeDefinition = EventTimeDefinition_CronNotation;
    type EventTimeDefinition_CronNotation = {
        cron?: string;
        zone?: string;
    };
    type EventFileDefinition = {
        path?: string | string[];
        trigger?: string | string[];
    };
    type EventKeyDefinition = string;
    type MakeDefinition = {
        file?: string | string[];
        state?: string;
    };
    type FileDefinition = {
        id?: string;
        path?: string | string[];
        source?: string | string[];
        state?: {
            [name: string]: TaskDefinition | string | (TaskDefinition | string)[];
        };
    };
    type TaskDefinition = {
        id?: string;
        action?: string;
        argument?: {
            [name: string]: any;
        };
    };
    type Config = {
        debug: boolean;
        path?: string;
        data: Map;
        events: Event[];
        files: File[];
        tasks: Task[];
    };
    type EventBase = {
        id: string;
        type: string;
        makeTargets: {
            files: string[];
            state: string;
        }[];
        runTargets: string[];
        enabled: boolean;
    };
    type Event = TimeEvent | FileEvent | KeyEvent;
    type TimeEvent = TimeEvent_CronNotation;
    type TimeEvent_CronNotation = EventBase & {
        type: 'time:cron';
        crontime: string;
        timezone: string;
    };
    type FileEvent = EventBase & {
        type: 'file';
        paths: string[];
        triggers: Trigger[];
    };
    type KeyEvent = EventBase & {
        type: 'key';
        key: string;
    };
    enum Trigger {
        Add = "add",
        Change = "change",
        Unlink = "unlink",
        AddDir = "addDir",
        UnlinkDir = "unlinkDir"
    }
    type File = {
        id: string;
        paths: string[];
        states: {
            [name: string]: (Task | string)[];
        };
    };
    type Task = {
        id: string;
        action: string;
        arguments: {
            [name: string]: any;
        };
    };
}
declare namespace influe {
    enum TouchPoint {
        Make = "Make",
        Watch = "Watch",
        Run = "Run",
        Test = "Test",
        Trace = "Trace",
        Config = "Config",
        Task = "Task"
    }
    function touch(point: TouchPoint, timing?: string, ...args: any[]): void;
}
declare namespace influe {
    function configure(path?: string): Config;
}
declare namespace influe.command {
    function make(config: Config, state: string): void;
}
declare namespace influe.command {
    function run(config: Config, taskId: string): void;
}
declare namespace influe.command {
    function watch(config: Config, configPath: string): void;
    function stopWatchAndExit(): void;
}
declare namespace influe.command {
    function test(config: Config): void;
}
declare namespace influe.command {
    function trace(config: Config): void;
}
declare namespace influe {
    const actions: {
        [name: string]: (context: Map, argument: Map) => Promise<void>;
    };
    function runAction(action: string, argument: Map, context: Map): void;
}
declare namespace influe {
}
declare namespace influe {
    type CommandArgument = {
        command: string[];
        cwd: string;
        env: $.Dictionary<string>;
    };
}
declare namespace influe {
}
declare namespace influe {
}
declare namespace influe {
}
declare namespace influe {
}
declare namespace influe {
}
declare namespace influe {
}
declare namespace influe.os {
    function readTextFile(path: string): string;
    function writeTextFile(path: string, content: string): void;
    function createImmidateDirectories(path: string): void;
    function unlinkFile(path: string): void;
    function executeShell(command: string, options?: ExecOptions): void;
    function executeCommand(command: string, args: string[], options?: SpawnOptions & {
        rawMode?: boolean;
    }): Promise<number | null>;
}
declare namespace influe {
    namespace DataReader {
        function isSupportFile(filePath: string): boolean;
        function read(filePath: string): Map;
        function readJson(filePath: string): Map;
    }
}
declare namespace influe {
    function expandTemplateText(text: string, context: Map, locals: Map): string;
    function evaluateExpression(context: Map, locals: Map, script: string, location?: string): string | null;
}
declare namespace influe {
    function runAll(config: Config, taskIds: string[]): void;
    function runTask(name: string, task: Task, context: Map): void;
    function makeAll(config: Config, targets: {
        files: string[];
        state: string;
    }[]): void;
    function updateFile(config: Config, file: File, state: string): void;
}
declare namespace influe {
    function startTimeWatch(config: Config): void;
    function stopTimeWatch(): void;
}
declare namespace influe {
    function startFileWatch(config: Config): void;
    function stopFileWatch(): void;
}
declare namespace influe {
    function startConsoleWatch(config: Config): Promise<void>;
    function stopConsoleWatch(): void;
    function pauseConsoleWatch(): void;
    function resumeConsoleWatch(): void;
}
export default influe;
//# sourceMappingURL=influe.d.ts.map